@@ -50,6 +50,35 @@ def decodeCustomTx(hex):
         res = decodePaybackLoanV2(hex[2:])
         if res != None:
             res['name'] = 'paybackloanv2'
+    elif functionMarker == 'a':
+        res = decodeAnyAccountsToAccounts(hex[2:])
+        if res != None:
+            res['name'] = 'anyaccountstoaccounts'
+    elif functionMarker == 'e':
+        res = decodeCloseVault(hex[2:])
+        if res != None:
+            res['name'] = 'closevault'
+    elif functionMarker == 'V':
+        res = decodeVault(hex[2:])
+        if res != None:
+            res['name'] = 'vault'
+    elif functionMarker == 'v':
+        res = decodeUpdateVault(hex[2:])
+        if res != None:
+            res['name'] = 'updatevault'
+    elif functionMarker == 'I':
+        res = decodeAuctionBid(hex[2:])
+        if res != None:
+            res['name'] = 'auctionbid'
+    elif functionMarker == 'J':
+        res = decodeWithdrawFromVault(hex[2:])
+        if res != None:
+            res['name'] = 'withdrawfromvault'
+    elif functionMarker == 'S':
+        res = decodeDepositToVault(hex[2:])
+        if res != None:
+            res['name'] = 'deposittovault'
+            
     else:
         c = CustomTxType()
         for key, value in asdict(c).items():
@@ -187,7 +216,7 @@ def decodePaybackLoan(hex):
     return searchHex(variables,hex)
 def decodePaybackLoanV2(hex):
     variables = [
-        {'bytesCount': 32,'key': 'vault', 'type': 'hex','endian':'little'},
+        {'bytesCount': 32,'key': 'vaultId', 'type': 'hex','endian':'little'},
         {'key': 'from', 'type': 'address','endian':None},
         {'key': 'tokens', 'type': [
             {'bytesCount': 1,'key': 'tokenId', 'type': int,'endian':None},
@@ -198,6 +227,70 @@ def decodePaybackLoanV2(hex):
         ]}
     ]
     return searchHex(variables,hex)
+def decodeAnyAccountsToAccounts(hex):
+    variables = [
+        {'key':'fromAddresses', 'type': [
+            {'key': 'from', 'type': 'address','endian':None},
+            {'key': 'amounts', 'type': [
+                {'bytesCount': 4,'key': 'tokenId', 'type': int,'endian':'little'},
+                {'bytesCount': 8, 'key': 'amount', 'type': int,'endian':'little'}
+                ]}
+        ]},
+        {'key':'toAddresses', 'type': [
+            {'key': 'to', 'type': 'address','endian':None},
+            {'key': 'amounts', 'type': [
+                {'bytesCount': 4,'key': 'tokenId', 'type': int,'endian':'little'},
+                {'bytesCount': 8, 'key': 'amount', 'type': int,'endian':'little'}
+                ]}
+        ]}
+    ]
+    return searchHex(variables,hex)
+def decodeCloseVault(hex):
+    variables = [
+        {'bytesCount': 32, 'key': 'vaultId', 'type': 'hex', 'endian':'little'},
+        {'key': 'shareAddress', 'type': 'address','endian':None}
+    ]
+    return searchHex(variables,hex)
+def decodeUpdateVault(hex):
+    variables = [
+        {'bytesCount': 32, 'key': 'vaultId', 'type': 'hex', 'endian':'little'},
+        {'key': 'ownerAddress', 'type': 'address','endian':None},
+        {'bytesCount': 1,'key': 'lengthLoanSchemeName', 'type': int,'endian':'little'},
+        {'bytesCount': 'rest', 'key': 'loanScheme', 'type': str,'endian':None}
+    ]
+    return searchHex(variables,hex)
+def decodeVault(hex):
+    variables = [
+        {'key': 'address', 'type': 'address','endian':None},
+        {'bytesCount': 1,'key': 'lengthLoanSchemeName', 'type': int,'endian':'little'},
+        {'bytesCount': 'rest', 'key': 'loanScheme', 'type': str,'endian':None}
+    ]
+    return searchHex(variables,hex)
+def decodeAuctionBid(hex):
+    variables = [
+        {'bytesCount': 32, 'key': 'vaultId', 'type': 'hex', 'endian':'little'},
+        {'bytesCount': 4,'key': 'index', 'type': int,'endian':'little'},
+        {'key': 'address', 'type': 'address','endian':None},
+        {'bytesCount': 1, 'key': 'tokenId', 'type': int,'endian':'little'},
+        {'bytesCount': 8,'key': 'amount', 'type': int,'endian':'little'}
+    ]
+    return searchHex(variables,hex)
+def decodeWithdrawFromVault(hex):
+    variables = [
+        {'bytesCount': 32, 'key': 'vaultId', 'type': 'hex', 'endian':'little'},
+        {'key': 'to', 'type': 'address','endian':None},
+        {'bytesCount': 1, 'key': 'tokenId', 'type': int,'endian':'little'},
+        {'bytesCount': 8,'key': 'amount', 'type': int,'endian':'little'}
+    ]
+    return searchHex(variables,hex)
+def decodeDepositToVault(hex):
+    variables = [
+        {'bytesCount': 32, 'key': 'vaultId', 'type': 'hex', 'endian':'little'},
+        {'key': 'from', 'type': 'address','endian':None},
+        {'bytesCount': 1, 'key': 'tokenId', 'type': int,'endian':'little'},
+        {'bytesCount': 8,'key': 'amount', 'type': int,'endian':'little'}
+    ]
+    return searchHex(variables,hex)
 def recursiveSearchHex(variable,hex):
     abort = False
     if type(variable['type']) == list:
@@ -272,8 +365,12 @@ def getValue(variable,hex):
         hexOfInterest = hex
         hex = ''
     else:
-        hexOfInterest = hex[:2*variable['bytesCount']]
-        hex = hex[2*variable['bytesCount']:]
+        if variable['bytesCount'] == 'rest':
+            hexOfInterest = hex
+            hex = ''
+        else:
+            hexOfInterest = hex[:2*variable['bytesCount']]
+            hex = hex[2*variable['bytesCount']:]
 
     # Handle Endian Transformation
     if variable['endian'] == 'big':
