@@ -130,7 +130,7 @@ def removePoolLiquidity(liquidity,reserveA,reserveB,totalLiquidity):
 
     return amountA.low64,amountB.low64
 
-def poolSwap(block,tokenFrom,poolSymbol,fromAmount,reserveA,reserveB,commission=0,dexfeeInPct=0,dexfeeOutPct=0):
+def poolSwap(block,fromAmount,isForward,reserveA,reserveB,commission=0,dexfeeInPct=0,dexfeeOutPct=0):
     # No Checks included! Only useable for valid block transactions!
     # https://github.com/DeFiCh/ain/blob/a7d914f15f762d121ac2c5d07d38d30cf7e09d4d/src/masternodes/poolpairs.cpp -> Swap
     # https://github.com/DeFiCh/ain/blob/d9a26cf042a4a6bb44c824c422990e6c3b4315e8/src/masternodes/mn_checks.cpp -> ExecuteSwap
@@ -139,12 +139,8 @@ def poolSwap(block,tokenFrom,poolSymbol,fromAmount,reserveA,reserveB,commission=
     # bool const forward = in.nTokenId == idTokenA;
     # auto& reserveF = forward ? reserveA : reserveB;
     # auto& reserveT = forward ? reserveB : reserveA;
-    if tokenFrom == poolSymbol.split('-')[0]:
-        bForward = True
-    else:
-        bForward = False
 
-    if bForward:
+    if isForward:
         reserveF = reserveA
         reserveT = reserveB
     else:
@@ -188,24 +184,31 @@ def poolSwap(block,tokenFrom,poolSymbol,fromAmount,reserveA,reserveB,commission=
     
     dexfeeOutAmount = int(swapped * dexfeeOutPct)
     swapped = swapped - dexfeeOutAmount
-    return int(poolFrom),int(poolTo),int(swapped),int(dexfeeInAmount),int(dexfeeOutAmount)
+
+    if isForward:
+        reserveAChange = poolFrom - reserveF
+        reserveBChange = poolTo - reserveT 
+    else:
+        reserveBChange = poolFrom - reserveF
+        reserveAChange = poolTo - reserveT 
+    return int(reserveAChange),int(reserveBChange),int(swapped),int(tradeFee),int(dexfeeInAmount),int(dexfeeOutAmount)
 
 # TEST FIRST FOUR DAX-DUSD TX
 # if __name__ == '__main__':
-#     amountA = 20000000
-#     amountB = 456000000
-#     reserveA = 0
-#     reserveB = 0
-#     totalLiq = 0
-#     i = addPoolLiquidity(amountA,amountB,reserveA,reserveB,totalLiq)
-#     print(i)
+# #     amountA = 20000000
+# #     amountB = 456000000
+# #     reserveA = 0
+# #     reserveB = 0
+# #     totalLiq = 0
+# #     i = addPoolLiquidity(amountA,amountB,reserveA,reserveB,totalLiq)
+# #     print(i)
 
-#     reserveA = amountA
-#     reserveB = amountB
-#     totalLiq = i
-#     amountA = 1000000
+#     reserveA = 100000000
+#     reserveB = 4066700000000
+#     totalLiq = 917403152
+#     amountA = 900000000
     
-#     poolF,poolT,swapped,dexIn,dexOut = poolSwap(2102372,'DUSD','DAX-DUSD',amountA,reserveA,reserveB,0.002,0.001)
+#     AChange,BChange,swapped,commission,dexIn,dexOut = poolSwap(480000,amountA,False,reserveA,reserveB,0.002,0.001,0.001)
 #     print(swapped)
 #     reserveA = poolT + 1 #correction
 #     reserveB = poolF
